library(ggplot2)
library(reshape2)
library(waffle) 
library(cowplot)  
library(tidyr)
library(dplyr)

#data preperation ----------------------------------------------------------------------
datacsv <- read.csv(file="./S5_2014-2018_summed_years_wheelload_SuppInfo.csv", 
        head=TRUE, sep=',', )
datacsv[datacsv<=0] <- NA

#---------------------------------------------------------------------
# round and aggregate values
name_table <- vector()
for (i in 2:13){
    name_table[i-1] <- names(datacsv)[i]
    sum_table <- vector()
    sum_table <- c(sum_table,round(datacsv[1,i]))
    sum_table <- c(sum_table,(round(datacsv[2,i]+datacsv[3,i])))
    sum_table <- c(sum_table,(round(datacsv[4,i]+datacsv[5,i])))
    sum_table <- c(sum_table,(round(datacsv[6,i]+datacsv[7,i])))
    sum_table <- c(sum_table,(round(datacsv[8,i]+datacsv[9,i])))
    sum_table <- c(sum_table,(round(datacsv[10,i]+datacsv[11,i])))
    sum_table <- c(sum_table,(round(datacsv[12,i]+datacsv[13,i]+datacsv[14,i]+datacsv[15,i]+datacsv[16,i])))
    sum_table <- c(sum_table,(round(datacsv[17,i]+datacsv[18,i]+datacsv[19,i]+datacsv[20,i]+datacsv[21,i])))
    sum_table <- c(sum_table,(round(datacsv[22,i])))
    sum_table <- c(sum_table,(round(datacsv[23,i])))
    sum_table <- c(sum_table,(round(datacsv[24,i])))
    sum_table <- c(sum_table,(round(datacsv[25,i])))
    
    if (i==2){
       sum_data_frame <- data.frame(sum_table)
       } else{
       sum_data_frame <- cbind(sum_data_frame,data.frame(sum_table))
       }
}

# ------------------------------------------------------------------------------
# transpose and seperate in infield and headland
legend_labels <- c("0","1-20","20-40","40-60","60-80","80-100","100-150",
              "150-200","200-300","300-400","400-500","500-600")
load_labels <- c(0,20,40,60,80,100,150,200,300,400,500,600)

colnames(sum_data_frame)<- name_table
sum_data_frame <- cbind(sum_data_frame,data.frame("tons"=load_labels))

transdata <- melt(sum_data_frame,id="tons")

y4 <- transdata[grep('infield',transdata[,2]),]
y4_headlands <- transdata[grep('headland',transdata[,2]),]
rm(transdata)

y4 <- drop_na(y4)
y4_headlands <- drop_na(y4_headlands)

y4$year <- substr(y4$variable,2,10)  
y4_headlands$year <- substr(y4_headlands$variable,2,10)

cols = c("#d9d9d9",'#543005','#8c510a','#bf812d','#dfc27d','#f6e8c3','#c7eae5','#80cdc1','#35978f','#01665e','#003c30','#ffff99')

#############################################################################################################
########################-------------- geom_waffle chart for infield
waffle_infield <- ggplot(y4, aes(fill = tons, values = value)) +
  geom_waffle(color = "white", size = .25, n_rows = 5, flip = TRUE) +
  facet_wrap(~year, nrow = 1, strip.position = "bottom") +
  scale_x_discrete() + 
  scale_y_continuous(labels = function(x) x * 5, # make this multiplyer the same as n_rows
                     expand = c(0,0)) +
  scale_fill_manual(values=cols,labels=legend_labels)+
  coord_equal() +
  labs(
    subtitle = "in the crop zone"
  ) +
  theme_minimal()+
  theme(panel.grid = element_blank(), axis.ticks.y = element_line(),legend.position="none") +
  guides(fill = guide_legend(reverse = TRUE))

  ########################-------------- geom_waffle chart for headlands
# only to get the legend
waffle_head <- ggplot(y4_headlands, aes(fill = tons, values = value)) +
  geom_waffle(color = "white", size = .25, n_rows = 5, flip = TRUE) +
  facet_wrap(~year, nrow = 1, strip.position = "bottom") +
  scale_x_discrete() + 
  scale_y_continuous(labels = function(x) x * 5, 
                     expand = c(0,0)) +
  scale_fill_manual(values=cols,labels=legend_labels)+
  coord_equal() +
  labs(
    subtitle = "in the headland"
  ) +
  theme_minimal()+
  theme(panel.grid = element_blank(), axis.ticks.y = element_line()) +
  guides(fill = guide_legend(reverse = TRUE))

g_plot_legend <- get_legend(waffle_head) # get legend of waffle head

# for plotting
waffle_head <- ggplot(y4_headlands, aes(fill = tons, values = value)) +
  geom_waffle(color = "white", size = .25, n_rows = 5, flip = TRUE) +
  facet_wrap(~year, nrow = 1, strip.position = "bottom") +
  scale_x_discrete() + 
  scale_y_continuous(labels = function(x) x * 5, # make this multiplyer the same as n_rows
                     expand = c(0,0)) +
  scale_fill_manual(values=cols,labels=legend_labels)+
  coord_equal() +
  labs(
    subtitle = "in the headland"
  ) +
  theme_minimal()+
  theme(panel.grid = element_blank(), axis.ticks.y = element_line(),legend.position="none") +
  guides(fill = guide_legend(reverse = TRUE))
  
  
g_plot <- plot_grid(waffle_infield,waffle_head,g_plot_legend,
       ncol=3, rel_widths=c(4,4,1)
       )
g_plot 

g_plot2 <- ggdraw(g_plot)+
  draw_plot_label("Percentage of area covered by classes of wheel load", x=0,y=1, size = 12, fontface="bold", hjus=-0.1, vjus=1.5)
g_plot2                     


ggsave("wheel_load_cumulative.pdf",g_plot,width=40, height=20, units='cm',dpi=600)

